@@ -1,5 +1,4 @@
-from skoobpy import get_all_books
-from skoobpy import save_desired_csv
+from skoobpy import *
 
 def main():
     from sys import argv
